############################################################
# CompMake - Component-oriented Cross-platform Make Library
# Copyright (C) 2003 Trevor A. Robinson
# See the accompanying LICENSE file for license information.
############################################################

############################################################
# Host OS determination
############################################################

#Environment-based host OS determination
ifndef HOST_OS

  ifeq ($(OS),Windows_NT)
    HOST_OS := win32
  endif

endif

#uname-based host OS determination
ifndef HOST_OS

  UNAME_OS := $(shell uname -s)

  ifeq ($(findstring CYGWIN,$(UNAME_OS)),CYGWIN)
    HOST_OS := win32
  endif

  ifeq ($(findstring indows,$(UNAME_OS)),indows)
    HOST_OS := win32
  endif

  ifeq ($(findstring inux,$(UNAME_OS)),inux)
    HOST_OS := linux
  endif

endif

ifndef HOST_OS
  $(error Unknown host OS)
endif

#TARGET_OS defaults to HOST_OS
ifndef TARGET_OS
  TARGET_OS := $(HOST_OS)
endif

############################################################
# Host architecture determination
############################################################

ifndef HOST_ARCH

  ifeq ($(HOST_OS),win32)

    ifdef $(PROCESSOR_ARCHITECTURE)
      #Use WinNT environment variable
      HOST_ARCH := $(PROCESSOR_ARCHITECTURE)
    else
      #Win9X is always x86
      HOST_ARCH := x86
    endif

  else

	#Use uname machine type for Unix (e.g. i586)
    HOST_ARCH := $(shell uname -m)

  endif

endif

ifndef HOST_ARCH
  $(error Unknown host architecture)
endif

#TARGET_OS defaults to HOST_OS
ifndef TARGET_ARCH
  TARGET_ARCH := $(HOST_ARCH)
endif

############################################################
# Host OS settings
############################################################

ifeq ($(HOST_OS),win32)

SLASH := \$(EMPTY)
SEP := ;

else

SLASH := /
SEP := :

endif

MKDIR := mkdir -p
RM := rm -rf
